@@ -1,21 +1,31 @@
 import os
-from pathlib import Path
 import re
-from typing import AnyStr, List
+from os.path import isfile
+from pathlib import Path
+from typing import AnyStr, List, Union
+
 from .dialogue import Dialogue
 
 
 class Subtitle(object):
     """
 
-    Converting ass to art
+    Converting ass to art.
 
     :type filepath: Path to a file that contains text in Advanced SubStation Alpha format
     """
 
-    def __init__(self, filepath: AnyStr):
-        self.filepath: AnyStr = filepath
-        self.file: AnyStr = Path(filepath).stem
+    def __init__(self, filepath: Union[str, os.PathLike]):
+        if not isfile(filepath):
+            raise FileNotFoundError('"{}" does not exist'.format(filepath))
+        if isinstance(filepath, os.PathLike):
+            self.filepath: AnyStr = str(filepath)
+            self.file: AnyStr = filepath.stem
+        elif isinstance(filepath, str):
+            self.filepath: AnyStr = filepath
+            self.file: AnyStr = Path(filepath).stem
+        else:
+            raise TypeError('"{}" is not of type str'.format(filepath))
         self.raw_text: AnyStr = self.get_text()
         self.dialogues: List = list()
 
@@ -53,7 +63,7 @@ class Subtitle(object):
     def subtitle_formatting(self, dialogues: List):
         """
 
-        Formatting ass into srt
+        Formatting ass into srt.
 
         :param dialogues: Prepared dialogues
         :return: Prepared dialogue sheet
@@ -77,6 +87,7 @@ class Subtitle(object):
         path = Path(self.filepath)
         file = self.file + ".srt"
         if output_dir:
+            Path(output_dir).mkdir(parents=True, exist_ok=True)
             out_path = os.path.join(output_dir, file)
         else:
             out_path = os.path.join(path.parent, file)
